pub enum HeaderType {
Normal(Normal),
Bridge(Bridge),
Cardbus(Cardbus),
Reserved(u8),
}Expand description
Identifies the layout of the second part of the predefined header (beginning at byte 10h in Configuration Space) and also whether or not the device contains multiple functions.
Variants
Implementations
Sourceimpl HeaderType
impl HeaderType
pub fn expansion_rom(&self) -> Option<ExpansionRom>